==> knative-client-4.9.0-sources.jar: io/fabric8/knative/client/flows/v1alpha1/internal/ParallelOperationsImpl.java <==

/**
 * Copyright (C) 2015 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

                        

package io.fabric8.knative.client.flows.v1alpha1.internal;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.knative.flows.v1alpha1.DoneableParallel;
import io.fabric8.knative.flows.v1alpha1.Parallel;
import io.fabric8.knative.flows.v1alpha1.ParallelList;
import io.fabric8.knative.flows.v1alpha1.DoneableParallel;

import java.util.Map;
import java.util.TreeMap;


public class ParallelOperationsImpl extends HasMetadataOperation<Parallel, ParallelList, DoneableParallel, Resource<Parallel, DoneableParallel>> {

  public ParallelOperationsImpl(OkHttpClient client, Config config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config));
  }

  public ParallelOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("flows.knative.dev")
    .withApiGroupVersion("v1alpha1")
    .withPlural("parallels"));
    this.type = Parallel.class;
    this.listType = ParallelList.class;
    this.doneableType = DoneableParallel.class;
  }

  public ParallelOperationsImpl newInstance(OperationContext context) {
    return new ParallelOperationsImpl(context);
  }
}

==> knative-client-4.10.0-sources.jar: io/fabric8/knative/client/flows/v1alpha1/internal/ParallelOperationsImpl.java <==


                        

package io.fabric8.knative.client.flows.v1alpha1.internal;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.knative.flows.v1alpha1.DoneableParallel;
import io.fabric8.knative.flows.v1alpha1.Parallel;
import io.fabric8.knative.flows.v1alpha1.ParallelList;
import io.fabric8.knative.flows.v1alpha1.DoneableParallel;

import java.util.Map;
import java.util.TreeMap;


public class ParallelOperationsImpl extends HasMetadataOperation<Parallel, ParallelList, DoneableParallel, Resource<Parallel, DoneableParallel>> {

  public ParallelOperationsImpl(OkHttpClient client, Config config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public ParallelOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("flows.knative.dev")
    .withApiGroupVersion("v1alpha1")
    .withPlural("parallels"));
    this.type = Parallel.class;
    this.listType = ParallelList.class;
    this.doneableType = DoneableParallel.class;
  }

  public ParallelOperationsImpl newInstance(OperationContext context) {
    return new ParallelOperationsImpl(context);
  }
}
